import java.awt.Shape;
import java.awt.geom.GeneralPath;
import java.awt.geom.Rectangle2D;
import java.util.LinkedList;


/**
 * Eine Schrankwand, die manipuliert werden kann und sich selbst auf einer Leinwand zeichnet.
 * 
 * @author Claus Albowski
 * @version  (feb 11)
 */
public class Schrankwand extends Moebel
{
    
    private LinkedList<Schrank> schraenke;
    private int anzahl;
    
    /**
     * Erzeuge eine neue Schrankwand mit einer Standardfarbe und Standardgroesse
     * an einer Standardposition. (Standardkonstruktor)
     */
    public Schrankwand(int anzahl) {
        xPosition = 10;
        yPosition = 10;
        farbe = "schwarz";
        orientierung = 0;
        istSichtbar = false;
        breite = anzahl*60;
        tiefe  = 37;
        initSchraenke(anzahl);
    }
    
    /**
     * Erzeuge eine neue Schrankwand.
     * Konstruktor, bei dem alle Attribute gesetzt werden können.
     */
    public Schrankwand(int xPosition,
                int yPosition,
                String farbe,
                int orientierung,
                int breite,
                int tiefe,
                int anzahl) {
        this.xPosition = xPosition;
        this.yPosition = yPosition;
        this.farbe = farbe;
        this.orientierung = orientierung;
        istSichtbar = false;
        this.breite = breite;
        this.tiefe  = tiefe;
        initSchraenke(anzahl);
    }
    
    /**
     * initialisiert die Schrankobjekte.
     * Das sollte im Konstruktor geschehen,  wird aber wegen der zwei Konstruktoren
     * in eine eigene Methode ausgegliedert.
     */
    private void initSchraenke(int anzahl){
        this.anzahl=anzahl;
        schraenke=new LinkedList();
        for (int i=0; i<anzahl; i++)
        schraenke.add(new Schrank(i*breite/anzahl, 0, farbe, 0, breite/anzahl, tiefe));
    }
    
    /**
     * Berechnet das zu zeichnende Shape anhand der gegebenen Daten
     */
    protected Shape gibAktuelleFigur() {
        // einen GeneralPath definieren
        GeneralPath schrankwand = new GeneralPath();
        for (Schrank schrank : schraenke)
        schrankwand.append(schrank.gibAktuelleFigur(), false);
        return transformiere(schrankwand);
    }
}
